@@ -4,6 +4,10 @@ KEY__attachment_name = "name"
 KEY__application = "application"
 KEY__application_description = "application_description"
 KEY__configuration = "configuration"
+KEY__schema = "schema"
+KEY__name = "name"
+KEY__is_default = "is_default"
+KEY__ip_id = "ip_id"
 KEY__configuration_name = "name"
 KEY__configuration_description = "configuration_description"
 KEY__exception = "exception"
@@ -13,6 +17,7 @@ KEY__uninstall_key = "uninstall_key"
 KEY__install_key = "install_key"
 KEY__deletion_key = "deletion_key"
 KEY__render_as = "render_as"
+KEY__default_tenant_password = "default_tenant_password"
 KEY__url = "url"
 KEY__superjaaql_password = "superjaaql_password"
 KEY__public_username = "public_username"
@@ -76,21 +81,32 @@ KEY__page = "page"
 KEY__use_mfa = "use_mfa"
 KEY__show_deleted = "show_deleted"
 KEY__description = "description"
+KEY__the_role = "the_role"
+KEY__tenant_admin_password = "tenant_admin_password"
+KEY__the_tenant = "the_tenant"
 KEY__database_name = "name"
 KEY__create = "create"
 KEY__drop = "drop"
 KEY__force_transactional = "force_transactional"
 KEY__port = "port"
+KEY__old_password = "old_password"
 KEY__address = "address"
+KEY__public_password = "public_password"
 KEY__jaaql_name = "jaaql_name"
+KEY__tenant_name = "name"
+KEY__level = "level"
+KEY__code = "code"
+KEY__access_rank = "access_rank"
 KEY__otp_uri = "otp_uri"
 KEY__otp_qr = "otp_qr"
-KEY__jaaql_otp_uri = "jaaql_otp_uri"
-KEY__jaaql_otp_qr = "jaaql_otp_qr"
+KEY__default_tenant_otp_uri = "default_tenant_otp_uri"
+KEY__default_tenant_otp_qr = "default_tenant_otp_qr"
 KEY__superjaaql_otp_uri = "superjaaql_otp_uri"
 KEY__superjaaql_otp_qr = "superjaaql_otp_qr"
 KEY__is_public = "is_public"
+KEY__count = "count"
 KEY__account = "account"
+KEY__enc_username = "enc_username"
 KEY__encrypted_password = "encrypted_password"
 KEY__email_template_name = "name"
 KEY__column_name = "column_name"
@@ -106,6 +122,9 @@ KEY__already_signed_up_email_template = "existing_user_template"
 KEY__allow_signup = "allow_signup"
 KEY__email_account_name = "name"
 KEY__email_sent = "sent"
+KEY__password_hash = "password_hash"
+KEY__tenant = "tenant"
+KEY__user_id = "user_id"
 KEY__body = "body"
 KEY__default_email_signup_template = "default_email_signup_template"
 KEY__default_email_already_signed_up_template = "default_email_already_signed_up_template"
@@ -117,6 +136,9 @@ KEY__email_account_host = "host"
 KEY__email_account_port = "port"
 KEY__email_account_username = "username"
 KEY__email_account_send_name = "send_name"
+KEY__encrypted_address = "encrypted_address"
+KEY__password_id = "password_id"
+KEY__created = "created"
 
 ATTR__deleted = "deleted"
 
@@ -160,6 +182,7 @@ EXAMPLE__jwt = "eyJ0eXAiOiJKV1QiLCJhbGciOiJIUzI1NiJ9.e30.yXvILkvUUCBqAFlAv6wQ1Q-
 VAULT_KEY__db_crypt_key = "db_crypt_key"
 VAULT_KEY__db_repeatable_salt = "repeatable_salt"
 VAULT_KEY__jaaql_local_access_key = "jaaql_access_key"
+VAULT_KEY__super_db_credentials = "super_db_credentials"
 VAULT_KEY__jaaql_lookup_connection = "jaaql_lookup_connection"
 VAULT_KEY__allow_jaaql_uninstall = "Allow jaaql uninstall"
 
@@ -197,7 +220,7 @@ HTML__base64_png = "data:image/png;base64,"
 FORMAT__png = "png"
 
 NODE__host_node = "host"
-DB__jaaql = "jaaql"
+DB__jaaql = "jaaql__jaaql"
 DB__postgres = "postgres"
 
 PORT__ems = 6061
@@ -221,5 +244,11 @@ DATASET__default_desc = "Default dataset description"
 HTTP_STATUS__too_early = 425  # Shiv for python 3.8
 
 USERNAME__jaaql = "jaaql"
+USERNAME__superjaaql = "superjaaql"
+USERNAME__super = "super"
+ROLE__jaaql = "jaaql"
+ROLE__postgres = "postgres"
 
-VERSION = "3.1.26"
+PROTOCOL__postgres = "postgresql://"
+
+VERSION = "3.2.0"
