@@ -1,3 +1,4 @@
+import traceback
 from abc import ABC, abstractmethod
 from datetime import datetime
 import logging
@@ -36,10 +37,10 @@ ERR__missing_database = "The database name was missing from the connection"
 class DBInterface(ABC):
 
     @abstractmethod
-    def __init__(self, config, address: str, username: str, dev_mode: bool = False):
+    def __init__(self, config, address: str, username: str):
         self.config = config
+        self.output_exceptions = self.config["DEBUG"]["output_query_exceptions"].lower() == "true"
         self.logging = config.get(KEY_CONFIG__system, {KEY_CONFIG__logging: True}).get(KEY_CONFIG__logging, True)
-        self.dev_mode = dev_mode
         self.username = username
         self.address = address
 
@@ -183,6 +184,8 @@ class DBInterface(ABC):
                             ret = resp
 
         except Exception as ex:
+            if self.output_exceptions:
+                traceback.print_exc()
             err = ex
 
         if commit:
