@@ -1,6 +1,6 @@
 from jaaql.exceptions.http_status_exception import HttpStatusException
 from jaaql.interpreter.interpret_jaaql import InterpretJAAQL
-from jaaql.constants import ENCODING__utf
+from jaaql.constants import ENCODING__utf, KEY__tenant
 from typing import Union
 import jaaql.utilities.crypt_utils as crypt_utils
 from jaaql.db.db_pg_interface import DBPGInterface
@@ -35,8 +35,7 @@ def try_encode(salt: Union[str, bytes]) -> bytes:
     return salt
 
 
-def create_interface(config, address: str, port: int, database: str, username: str, password: str,
-                     is_jaaql_user: bool = False, dev_mode: bool = False):
+def create_interface(config, address: str, port: int, database: str, username: str, password: str = None, role: str = None):
     interface = config[KEY_CONFIG__db][KEY_CONFIG__interface]
     supported = {
         INTERFACE__postgres_key: INTERFACE__postgres_class
@@ -47,7 +46,7 @@ def create_interface(config, address: str, port: int, database: str, username: s
 
     # interface_class = getattr(db, supported[interface])  To implement later for accessing non postgres databases
     interface_class = DBPGInterface
-    instance = interface_class(config, address, port, database, username, password, is_jaaql_user, dev_mode)
+    instance = interface_class(config, address, port, database, username, role=role, password=password)
 
     return instance
 
@@ -55,7 +54,7 @@ def create_interface(config, address: str, port: int, database: str, username: s
 def execute_supplied_statement(db_interface, query: str, parameters: dict = None,
                                as_objects: bool = False, encrypt_parameters: list = None,
                                decrypt_columns: list = None, encryption_key: bytes = None,
-                               encryption_salts: dict = None):
+                               encryption_salts: dict = None, skip_commit: bool = False):
     if parameters is None:
         parameters = {}
 
@@ -100,7 +99,19 @@ def execute_supplied_statement(db_interface, query: str, parameters: dict = None
         "parameters": parameters
     }
 
-    data = InterpretJAAQL(db_interface).transform(statement)
+    conn = None
+    if skip_commit:
+        conn = db_interface.get_conn()
+
+    try:
+        data = InterpretJAAQL(db_interface).transform(statement)
+    except Exception as ex:
+        if skip_commit:
+            db_interface.put_conn(conn)
+        raise ex
+
+    if skip_commit:
+        db_interface.put_conn(conn)
 
     missing = [param for param in decrypt_columns if param not in data["columns"]]
     if len(missing) != 0:
@@ -142,9 +153,9 @@ def execute_supplied_statement_singleton(db_interface, query, parameters: dict =
                                          as_objects: bool = False, encrypt_parameters: list = None,
                                          decrypt_columns: list = None, encryption_key: bytes = None,
                                          encryption_salts: dict = None, singleton_code: int = None,
-                                         singleton_message: str = None):
+                                         singleton_message: str = None, skip_commit: bool = False):
     data = execute_supplied_statement(db_interface, query, parameters, as_objects, encrypt_parameters,
-                                      decrypt_columns, encryption_key, encryption_salts)
+                                      decrypt_columns, encryption_key, encryption_salts, skip_commit=skip_commit)
 
     return force_singleton(data, as_objects, singleton_code, singleton_message)
 
