@@ -55,6 +55,8 @@ class EmailManager:
 
         if not app_relative_path.endswith(".html"):
             app_relative_path = app_relative_path + ".html"
+        if not isinstance(app_relative_path, str) or any([not letter.isalnum() and letter not in ['-', '_'] for letter in app_relative_path]):
+            raise Exception("Database has been tampered with! Cannot send email")
         if app_url is None or app_url.startswith(base_url) or (
                 not app_url.startswith("https://") and not app_url.startswith("http://")):
             return open(join("www", "templates", app_relative_path), "r").read()
