@@ -71,9 +71,9 @@ def create_app(is_gunicorn: bool = False, override_config_path: str = None, migr
     if len(options) == 0 and not is_gunicorn:
         options = parse_options(sys.argv, False, additional_options=additional_options)
 
-    if not is_gunicorn and start_email_service:
-        threading.Thread(target=create_email_service_app, args=[options.get(OPT_KEY__vault_key), options.get(OPT_KEY__email_credentials)],
-                         daemon=True).start()
+    # if not is_gunicorn and start_email_service:
+    #     threading.Thread(target=create_email_service_app, args=[options.get(OPT_KEY__vault_key), options.get(OPT_KEY__email_credentials)],
+    #                      daemon=True).start()
     if not is_gunicorn:
         threading.Thread(target=bootup, args=[options.get(OPT_KEY__vault_key), False, OPT_KEY__local_install in options], daemon=True).start()
 
@@ -96,12 +96,10 @@ def create_app(is_gunicorn: bool = False, override_config_path: str = None, migr
 
     force_mfa = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__force_mfa] in ("true", "True", True, "TRUE")
     do_audit = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__do_audit] in ("true", "True", True, "TRUE")
-    invite_only = config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__invite_only] in ("true", "True", True, "TRUE")
 
     # The following code sets it "properly" in case it is accessed incorrectly from elsewhere
     config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__force_mfa] = force_mfa
     config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__do_audit] = do_audit
-    config[CONFIG_KEY__security][CONFIG_KEY_SECURITY__invite_only] = invite_only
 
     if not do_audit:
         print(WARNING__audit_off, file=sys.stderr)
