@@ -42,7 +42,7 @@ def fetch_epoch_ms():
 def jwt_encode(secret_key: bytes, data: dict, purpose: str, expiry_ms: int = JWT__hour_expiry) -> str:
     data[JWT__exp] = (fetch_epoch_ms() + expiry_ms) if expiry_ms != 0 else MAX_LONG
     data[JWT__purpose] = purpose
-    return jwt.encode(data, secret_key, algorithm=JWT__algo).decode(ENCODING__ascii)
+    return jwt.encode(data, secret_key, algorithm=JWT__algo)
 
 
 def jwt_decode(secret_key: bytes, data: str, purpose: str, allow_expired: bool = False) -> Union[dict, bool]:
